<?php
class iPaper
{
    // For information on the iPaper Javascript Viewer API, see: 
    // http://www.scribd.com/platform/documentation/viewer
    
    // Array of available public parameters. 0 = false, 1 = true
    public static $availablePublicParameters = array('0', '1');
    
    // Array of available mode parameters.
    public static $availableModeParameters = array('list', 'book', 'slideshow', 'tile');
    
    // Array of file formats supported by iPaper.
    // For supported formats see: http://www.scribd.com/platform/faq#faq_question_74
    public static $availableSupportedFormats = array(
        'pdf' => 'Portable Document Format File', 
        'ps'  => 'PostScript File', 
        'doc' => 'Microsoft Word Document', 
        'ppt' => 'PowerPoint Presentation', 
        'pps' => 'PowerPoint Slide Show', 
        'xls' => 'Microsoft Excel Spreadsheet', 
        'odt' => 'OpenDocument Text Document', 
        'sxw' => 'StarOffice Text Document', 
        'odp' => 'OpenDocument Presentation', 
        'sxi' => 'StarOffice Impress Presentation', 
        'ods' => 'OpenDocument Spreadsheet', 
        'sxc' => 'StarOffice Calc Spreadsheet', 
        'odg' => 'OpenDocument Graphic', 
        'odf' => 'OpenDocument Formula', 
        'txt' => 'Text File', 
        'rtf' => 'Rich Text Format'
    );
    
    public function __construct() {}
    
    public function setScribdPublisherId()
    {
        $this->scribdPublisherId = get_option('iPaper_scribdPublisherId');
    }
    
    public function setPublicParameter()
    {
        $this->publicParameter = get_option('iPaper_publicParameter');
    }
    
    public function setModeParameter()
    {
        $this->modeParameter = get_option('iPaper_modeParameter');
    }
    
    public function setSupportedFormats()
    {
        $this->supportedFormats = unserialize(get_option('iPaper_supportedFormats'));
    }
    
    public function setHeight()
    {
        $this->height = get_option('iPaper_height');
    }
    
    public function setWidth()
    {
        $this->width = get_option('iPaper_width');
    }
    
    public function setShowAdmin()
    {
        $this->showAdmin = get_option('iPaper_showAdmin');
    }

    public function setShowPublic()
    {
        $this->showPublic = get_option('iPaper_showPublic');
    }

    public function setItem($item)
    {
        $this->item = $item;
    }

    public function validateEmbed()
    {        
        if ($this->scribdPublisherId === null) {
            throw new Exception('No Scribd Publisher ID');
        }
        if (!in_array($this->publicParameter, self::$availablePublicParameters)) {
            throw new Exception('Invalid public parameter');
        }
        if (!in_array($this->modeParameter, self::$availableModeParameters)) {
            throw new Exception('Invalid mode parameter');
        }
        if (!count($this->supportedFormats)) {
            throw new Exception('No supported formats are selected');
        }
        if (!is_numeric($this->height) && !empty($this->height)) {
            throw new Exception('Invalid height');
        }
        if (!is_numeric($this->width) && !empty($this->width)) {
            throw new Exception('Invalid width');
        }
        if (!$this->item instanceof Item) {
            throw new Exception('Invalid Item object');
        }
    }
    
    public function embed()
    {
        // Set the regular expression to match selected/supported formats.
        $supportedFormatRegEx = '/\.'.implode('|', array_keys($this->supportedFormats)).'$/';
        
        $i = 1;
        // Iterate through the item's files.
        foreach($this->item->Files as $file) {
            
            // Embed only those files that end with the selected/supported formats.
            if (preg_match($supportedFormatRegEx, $file->archive_filename)) {
                
                // Set the document's absolute URL.
                // Note: file_download_uri($file) does not work here. It results 
                // in the iPaper error: "Unable to reach provided URL."
                $documentUrl = WEB_FILES.'/'.$file->archive_filename;
?>
<h2 class="ipaper_embedded_document_header"><?php echo $file->original_filename; ?></h2>
<div id="ipaper_embedded_document_<?php echo $i; ?>" class="ipaper_embedded_document"></div>
<script type="text/javascript">
    var scribd_doc = scribd.Document.getDocFromUrl("<?php echo $documentUrl; ?>", 
    "<?php echo $this->scribdPublisherId; ?>");
    scribd_doc.addParam("public", <?php echo $this->publicParameter ? 'true' : 'false'; ?>);
    scribd_doc.addParam("mode", "<?php echo $this->modeParameter; ?>");
    scribd_doc.addParam("height", "<?php echo $this->height; ?>");
    scribd_doc.addParam("width", "<?php echo $this->width; ?>");
    scribd_doc.write("ipaper_embedded_document_<?php echo $i; ?>");
</script>
<?php
                $i++;
            }
        }
    }
}
?>
